==> ksocrat_3.1.2.orig.tar.gz: ksocrat-3.1.2/ksocrat/sconfigure.h <==
/*
    KSocrat
    Version 3.1.2, 28 April 2003    
    (C) 2000-2003 Zavolzhsky Alexandr <zavolzhsky@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
*/

#ifndef SCONFIGURE_H
#define SCONFIGURE_H

#include <qwidget.h>
#include <qgroupbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qdialog.h>
#include <qcheckbox.h>
#include <kapp.h>

class SConfigure : public QDialog  {
   Q_OBJECT
public: 
    SConfigure(QWidget *parent=0, const char *name=0);
    ~SConfigure();
    KConfig *config;

protected: 
    void initDialog();
    QGroupBox *gbConfigure;
    QLineEdit *edEnRuPath;
    QPushButton *btBrowse1;
    QLabel *lbEnRu;
    QLineEdit *edRuEnPath;
    QPushButton *btBrowse2;
    QLabel *lbRuEn;
    QPushButton *btOk;
    QPushButton *btCancel;
    QGroupBox *gbFont;
    QLabel *lbFont;
    QPushButton *btFont;
    QPushButton *btClrHist;
    QCheckBox *cbHideOnStartUp;

public slots:
  void cancel();
  void save();
  void browseEnRu();
  void browseRuEn();
  void changeFont();
  void clearHistory();
};

#endif

==> ksocrat_3.2.1.orig.tar.gz: ksocrat-3.2.1/ksocrat/sconfigure.h <==
/*
    KSocrat
    Version 3.2.1, 17 July 2004
    (C) 2000-2004 Zavolzhsky Alexandr <zavolzhsky@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
*/

#ifndef SCONFIGURE_H
#define SCONFIGURE_H

#include <qwidget.h>
#include <qgroupbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <kdialogbase.h>
#include <qcheckbox.h>
#include <kapp.h>

class SConfigure : public KDialogBase  {
   Q_OBJECT
public: 
    SConfigure(QWidget *parent=0, const char *name=0);
    ~SConfigure();
    KConfig *config;

protected: 
    void initDialog();
    QGroupBox *gbConfigure;
    QLineEdit *edEnRuPath;
    QPushButton *btBrowse1;
    QLabel *lbEnRu;
    QLineEdit *edRuEnPath;
    QPushButton *btBrowse2;
    QLabel *lbRuEn;
    QPushButton *btOk;
    QPushButton *btCancel;
    QGroupBox *gbFont;
    QLabel *lbFont;
    QPushButton *btFont;
    QPushButton *btClrHist;
    QCheckBox *cbHideOnStartUp;

public slots:
  void save();
  void browseEnRu();
  void browseRuEn();
  void changeFont();
  void clearHistory();
};

#endif
